@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
 our $DATE = '2016-12-27'; # DATE
-our $VERSION = '0.48'; # VERSION
+our $VERSION = '0.49'; # VERSION
 
 use 5.010001;
 use strict;
@@ -329,8 +329,14 @@ sub lint_prereqs {
 
             my $mod = $param;
             if ($phase eq 'Develop' && $rel eq 'Suggests') {
-                # strip extra relationship information, e.g. _SPEC::, _EMBED::
-                $mod =~ s/\A_[A-Z]+:://;
+                # strip extra relationship information in prefix, e.g. _SPEC::, _EMBED::
+                my $extrarel;
+                if ($mod =~ s/\A(_[A-Z]+):://) {
+                    $extrarel = $1;
+                }
+                if (defined $extrarel && $extrarel !~ /\A(_EMBED)\z/) {
+                    next;
+                }
             }
 
             $mods_from_ini{$phase}{$mod}   = $v unless $section =~ /assume-provided/;
@@ -665,7 +671,7 @@ App::LintPrereqs - Check extraneous/missing/incorrect prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.48 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-12-27.
+This document describes version 0.49 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-12-27.
 
 =head1 SYNOPSIS
 
